@@ -1,5 +1,5 @@
 .\"
-.\" $Id$
+.\" $Id: tmac.h.in,v 1.1.1.1 1999/04/30 18:08:35 doug Exp $
 .\"    Try to keep only one copy of the documentation around
 .\"    by re-defining macros and so forth.
 .\"
@@ -7,7 +7,7 @@
 .\"    I pity the fool who tampers with the next line...
 .ds ZZ -man
 .de SC					\" Title section
-.TH \\$1 \\$2 MH.6.8 [nmh-1.0]
+.TH \\$1 \\$2 MH.6.8 [nmh-1.0.4]
 ..
 .de NA					\" Name section
 .SH NAME
